Struct LateParamRegion
pub struct LateParamRegion<'db> {
pub scope: SolverDefId,
pub bound_region: BoundRegionKind<DbInterner<'db>>,
}Expand description
The parameter representation of late-bound function parameters, “some region
at least as big as the scope fr.scope”.
Similar to a placeholder region as we create LateParam regions when entering a binder
except they are always in the root universe and instead of using a boundvar to distinguish
between others we use the DefId of the parameter. For this reason the bound_region field
should basically always be BoundRegionKind::Named as otherwise there is no way of telling
different parameters apart.
Fields
scope: SolverDefIdbound_region: BoundRegionKind<DbInterner<'db>>Trait Implementations
impl<'db> Clone for LateParamRegion<'db>
impl<'db> Clone for LateParamRegion<'db>
fn clone(&self) -> LateParamRegion<'db>
fn clone(&self) -> LateParamRegion<'db>
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Debug for LateParamRegion<'_>
impl Debug for LateParamRegion<'_>
impl<'db, __V> GenericTypeVisitable<__V> for LateParamRegion<'db>where
__V: WorldExposer,
impl<'db, __V> GenericTypeVisitable<__V> for LateParamRegion<'db>where
__V: WorldExposer,
fn generic_visit_with(&self, __visitor: &mut __V)
impl<'db> Hash for LateParamRegion<'db>
impl<'db> Hash for LateParamRegion<'db>
impl<'db> PartialEq for LateParamRegion<'db>
impl<'db> PartialEq for LateParamRegion<'db>
impl<'db> Copy for LateParamRegion<'db>
impl<'db> Eq for LateParamRegion<'db>
impl<'db> StructuralPartialEq for LateParamRegion<'db>