Type Alias AliasTy
pub type AliasTy<'db> = AliasTy<DbInterner<'db>>;Aliased Type
pub struct AliasTy<'db> {
pub args: GenericArgs<'db>,
pub kind: AliasTyKind<DbInterner<'db>>,
/* private fields */
}Fields
args: GenericArgs<'db>The parameters of the associated or opaque type.
For a projection, these are the generic parameters for the trait and the GAT parameters, if there are any.
For an inherent projection, they consist of the self type and the GAT parameters, if there are any.
For RPIT the generic parameters are for the generics of the function, while for TAIT it is used for the generic parameters of the alias.
kind: AliasTyKind<DbInterner<'db>>