Struct LateParamRegion
pub struct LateParamRegion {
pub scope: SolverDefId,
pub bound_region: BoundRegionKind,
}Expand description
The parameter representation of late-bound function parameters, “some region
at least as big as the scope fr.scope”.
Similar to a placeholder region as we create LateParam regions when entering a binder
except they are always in the root universe and instead of using a boundvar to distinguish
between others we use the DefId of the parameter. For this reason the bound_region field
should basically always be BoundRegionKind::Named as otherwise there is no way of telling
different parameters apart.
Fields
scope: SolverDefIdbound_region: BoundRegionKindTrait Implementations
impl Clone for LateParamRegion
impl Clone for LateParamRegion
fn clone(&self) -> LateParamRegion
fn clone(&self) -> LateParamRegion
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Debug for LateParamRegion
impl Debug for LateParamRegion
impl<V> GenericTypeVisitable<V> for LateParamRegion
impl<V> GenericTypeVisitable<V> for LateParamRegion
fn generic_visit_with(&self, _visitor: &mut V)
fn generic_visit_with(&self, _visitor: &mut V)
The entry point for visiting. To visit a value
t with a visitor v
call: t.generic_visit_with(v). Read moreimpl Hash for LateParamRegion
impl Hash for LateParamRegion
impl PartialEq for LateParamRegion
impl PartialEq for LateParamRegion
impl<'db> TypeFoldable<DbInterner<'db>> for LateParamRegion
impl<'db> TypeFoldable<DbInterner<'db>> for LateParamRegion
fn try_fold_with<F>(
self,
_: &mut F,
) -> Result<LateParamRegion, <F as FallibleTypeFolder<DbInterner<'db>>>::Error>where
F: FallibleTypeFolder<DbInterner<'db>>,
fn try_fold_with<F>(
self,
_: &mut F,
) -> Result<LateParamRegion, <F as FallibleTypeFolder<DbInterner<'db>>>::Error>where
F: FallibleTypeFolder<DbInterner<'db>>,
fn fold_with<F>(self, _: &mut F) -> LateParamRegionwhere
F: TypeFolder<DbInterner<'db>>,
fn fold_with<F>(self, _: &mut F) -> LateParamRegionwhere
F: TypeFolder<DbInterner<'db>>,
impl<'db> TypeVisitable<DbInterner<'db>> for LateParamRegion
impl<'db> TypeVisitable<DbInterner<'db>> for LateParamRegion
fn visit_with<F>(
&self,
_: &mut F,
) -> <F as TypeVisitor<DbInterner<'db>>>::Resultwhere
F: TypeVisitor<DbInterner<'db>>,
fn visit_with<F>(
&self,
_: &mut F,
) -> <F as TypeVisitor<DbInterner<'db>>>::Resultwhere
F: TypeVisitor<DbInterner<'db>>,
impl Copy for LateParamRegion
impl Eq for LateParamRegion
impl StructuralPartialEq for LateParamRegion