Struct ScalarInt
#[repr(packed(1))]pub struct ScalarInt {
data: u128,
size: NonZero<u8>,
}Expand description
The raw bytes of a simple value.
This is a packed struct in order to allow this type to be optimally embedded in enums (like Scalar).
Fields
data: u128size: NonZero<u8>Implementations
impl ScalarInt
impl ScalarInt
pub const TRUE: ScalarInt
pub const FALSE: ScalarInt
pub fn size(self) -> Size
pub fn null(size: Size) -> ScalarInt
pub fn is_null(self) -> bool
pub fn try_from_uint(i: impl Into<u128>, size: Size) -> Option<ScalarInt>
pub fn truncate_from_uint(i: impl Into<u128>, size: Size) -> (ScalarInt, bool)
pub fn truncate_from_uint(i: impl Into<u128>, size: Size) -> (ScalarInt, bool)
Returns the truncated result, and whether truncation changed the value.
pub fn try_from_int(i: impl Into<i128>, size: Size) -> Option<ScalarInt>
pub fn truncate_from_int(i: impl Into<i128>, size: Size) -> (ScalarInt, bool)
pub fn truncate_from_int(i: impl Into<i128>, size: Size) -> (ScalarInt, bool)
Returns the truncated result, and whether truncation changed the value.
pub fn try_from_target_usize( i: impl Into<u128>, data_layout: &TargetDataLayout, ) -> Option<ScalarInt>
pub fn try_to_bits(self, target_size: Size) -> Result<u128, Size>
pub fn try_to_bits(self, target_size: Size) -> Result<u128, Size>
Try to convert this ScalarInt to the raw underlying bits.
Fails if the size is wrong. Generally a wrong size should lead to a panic,
but Miri sometimes wants to be resilient to size mismatches,
so the interpreter will generally use this try method.
pub fn to_bits(self, target_size: Size) -> u128
pub fn to_bits_unchecked(self) -> u128
pub fn to_bits_unchecked(self) -> u128
Extracts the bits from the scalar without checking the size.
pub fn to_uint(self, size: Size) -> u128
pub fn to_uint(self, size: Size) -> u128
Converts the ScalarInt to an unsigned integer of the given size.
Panics if the size of the ScalarInt is not equal to size.
pub fn to_uint_unchecked(self) -> u128
pub fn to_u8(self) -> u8
pub fn to_u8(self) -> u8
Converts the ScalarInt to u8.
Panics if the size of the ScalarIntin not equal to 1 byte.
pub fn to_u16(self) -> u16
pub fn to_u16(self) -> u16
Converts the ScalarInt to u16.
Panics if the size of the ScalarInt in not equal to 2 bytes.
pub fn to_u32(self) -> u32
pub fn to_u32(self) -> u32
Converts the ScalarInt to u32.
Panics if the size of the ScalarInt in not equal to 4 bytes.
pub fn to_u64(self) -> u64
pub fn to_u64(self) -> u64
Converts the ScalarInt to u64.
Panics if the size of the ScalarInt in not equal to 8 bytes.
pub fn to_u128(self) -> u128
pub fn to_u128(self) -> u128
Converts the ScalarInt to u128.
Panics if the size of the ScalarInt in not equal to 16 bytes.
pub fn to_target_usize(&self, data_layout: &TargetDataLayout) -> u64
pub fn try_to_bool(self) -> Result<bool, ()>
pub fn try_to_bool(self) -> Result<bool, ()>
Converts the ScalarInt to bool.
Panics if the size of the ScalarInt is not equal to 1 byte.
Errors if it is not a valid bool.
pub fn to_int(self, size: Size) -> i128
pub fn to_int(self, size: Size) -> i128
Converts the ScalarInt to a signed integer of the given size.
Panics if the size of the ScalarInt is not equal to size.
pub fn to_int_unchecked(self) -> i128
pub fn to_i8(self) -> i8
pub fn to_i8(self) -> i8
Converts the ScalarInt to i8.
Panics if the size of the ScalarInt is not equal to 1 byte.
pub fn to_i16(self) -> i16
pub fn to_i16(self) -> i16
Converts the ScalarInt to i16.
Panics if the size of the ScalarInt is not equal to 2 bytes.
pub fn to_i32(self) -> i32
pub fn to_i32(self) -> i32
Converts the ScalarInt to i32.
Panics if the size of the ScalarInt is not equal to 4 bytes.
pub fn to_i64(self) -> i64
pub fn to_i64(self) -> i64
Converts the ScalarInt to i64.
Panics if the size of the ScalarInt is not equal to 8 bytes.
pub fn to_i128(self) -> i128
pub fn to_i128(self) -> i128
Converts the ScalarInt to i128.
Panics if the size of the ScalarInt is not equal to 16 bytes.
pub fn to_target_isize(&self, data_layout: &TargetDataLayout) -> i64