Type Alias ValTreeKind
pub type ValTreeKind<'db> = ValTreeKind<DbInterner<'db>>;Aliased Type
pub enum ValTreeKind<'db> {
Leaf(ScalarInt),
Branch(Consts<'db>),
}Variants
Leaf(ScalarInt)
integers, bool, char are represented as scalars.
See the ScalarInt documentation for how ScalarInt guarantees that equal values
of these types have the same representation.
Branch(Consts<'db>)
The fields of any kind of aggregate. Structs, tuples and arrays are represented by listing their fields’ values in order.
Enums are represented by storing their variant index as a u32 field, followed by all the fields of the variant.
ZST types are represented as an empty slice.